@@ -15,7 +15,7 @@ var _ = Describe("Generating fluentd config", func() {
 	)
 	BeforeEach(func() {
 		var err error
-		generator, err = NewConfigGenerator(true, true)
+		generator, err = NewConfigGenerator(false, false)
 		Expect(err).To(BeNil())
 		Expect(generator).ToNot(BeNil())
 		forwarding = &logging.ForwardingSpec{
@@ -375,14 +375,6 @@ var _ = Describe("Generating fluentd config", func() {
 						@type relabel
 						@label @APPS_PIPELINE
 					</store>
-					<store>
-						@type relabel
-						@label @_LEGACY_SECUREFORWARD
-					</store>
-					<store>
-						@type relabel
-						@label @_LEGACY_SYSLOG
-					</store>
 				</match>
 			</label>
 
@@ -405,7 +397,7 @@ var _ = Describe("Generating fluentd config", func() {
 				<buffer>
 					@type file
 					path '/var/lib/fluentd/secureforward_receiver'
-					queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '1024' }"
+					queue_limit_length "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
 					chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '1m' }"
 					flush_interval "#{ENV['FORWARD_FLUSH_INTERVAL'] || '5s'}"
 					flush_at_shutdown "#{ENV['FLUSH_AT_SHUTDOWN'] || 'false'}"
@@ -424,20 +416,6 @@ var _ = Describe("Generating fluentd config", func() {
 				</server>
 			</match>
 		</label>
-		<label @_LEGACY_SECUREFORWARD>
-			<match **>
-				@type copy
-				#include legacy secure-forward.conf
-				@include /etc/fluent/configs.d/secure-forward/secure-forward.conf
-			</match>
-		</label>
-		<label @_LEGACY_SYSLOG>
-			<match **>
-				@type copy
-				#include legacy Syslog
-				@include /etc/fluent/configs.d/syslog/syslog.conf
-			</match>
-		</label>
 	`)
 	})
 
@@ -789,7 +767,6 @@ var _ = Describe("Generating fluentd config", func() {
 				<match **>
 					@type stdout
 				</match>
-
 			</label>
 			
 			# Relabel specific sources (e.g. logs.apps) to multiple pipelines
@@ -800,14 +777,6 @@ var _ = Describe("Generating fluentd config", func() {
 						@type relabel
 						@label @APPS_PIPELINE
 					</store>
-					<store>
-						@type relabel
-						@label @_LEGACY_SECUREFORWARD
-					</store>
-					<store>
-						@type relabel
-						@label @_LEGACY_SYSLOG
-					</store>
 				</match>
 			</label>
 			<label @_LOGS_AUDIT>
@@ -817,14 +786,6 @@ var _ = Describe("Generating fluentd config", func() {
 						@type relabel
 						@label @AUDIT_PIPELINE
 					</store>
-					<store>
-						@type relabel
-						@label @_LEGACY_SECUREFORWARD
-					</store>
-					<store>
-						@type relabel
-						@label @_LEGACY_SYSLOG
-					</store>
 				</match>
 			</label>
 			<label @_LOGS_INFRA>
@@ -834,14 +795,6 @@ var _ = Describe("Generating fluentd config", func() {
 						@type relabel
 						@label @INFRA_PIPELINE
 					</store>
-					<store>
-						@type relabel
-						@label @_LEGACY_SECUREFORWARD
-					</store>
-					<store>
-						@type relabel
-						@label @_LEGACY_SYSLOG
-					</store>
 				</match>
 			</label>
 
@@ -916,7 +869,7 @@ var _ = Describe("Generating fluentd config", func() {
 							flush_at_shutdown "#{ENV['FLUSH_AT_SHUTDOWN'] || 'false'}"
 							retry_max_interval "#{ENV['ES_RETRY_WAIT'] || '300'}"
 							retry_forever true
-							queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
+							queue_limit_length "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
 							chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m' }"
 							overflow_action "#{ENV['BUFFER_QUEUE_FULL_ACTION'] || 'block'}"
 						</buffer>
@@ -959,7 +912,7 @@ var _ = Describe("Generating fluentd config", func() {
 							flush_at_shutdown "#{ENV['FLUSH_AT_SHUTDOWN'] || 'false'}"
 							retry_max_interval "#{ENV['ES_RETRY_WAIT'] || '300'}"
 							retry_forever true
-							queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
+							queue_limit_length "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
 							chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m' }"
 							overflow_action "#{ENV['BUFFER_QUEUE_FULL_ACTION'] || 'block'}"
 						</buffer>
@@ -1003,7 +956,7 @@ var _ = Describe("Generating fluentd config", func() {
 							flush_at_shutdown "#{ENV['FLUSH_AT_SHUTDOWN'] || 'false'}"
 							retry_max_interval "#{ENV['ES_RETRY_WAIT'] || '300'}"
 							retry_forever true
-							queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
+							queue_limit_length "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
 							chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m' }"
 							overflow_action "#{ENV['BUFFER_QUEUE_FULL_ACTION'] || 'block'}"
 						</buffer>
@@ -1046,7 +999,7 @@ var _ = Describe("Generating fluentd config", func() {
 							flush_at_shutdown "#{ENV['FLUSH_AT_SHUTDOWN'] || 'false'}"
 							retry_max_interval "#{ENV['ES_RETRY_WAIT'] || '300'}"
 							retry_forever true
-							queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
+							queue_limit_length "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
 							chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m' }"
 							overflow_action "#{ENV['BUFFER_QUEUE_FULL_ACTION'] || 'block'}"
 						</buffer>
@@ -1090,7 +1043,7 @@ var _ = Describe("Generating fluentd config", func() {
 							flush_at_shutdown "#{ENV['FLUSH_AT_SHUTDOWN'] || 'false'}"
 							retry_max_interval "#{ENV['ES_RETRY_WAIT'] || '300'}"
 							retry_forever true
-							queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
+							queue_limit_length "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
 							chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m' }"
 							overflow_action "#{ENV['BUFFER_QUEUE_FULL_ACTION'] || 'block'}"
 						</buffer>
@@ -1133,7 +1086,7 @@ var _ = Describe("Generating fluentd config", func() {
 							flush_at_shutdown "#{ENV['FLUSH_AT_SHUTDOWN'] || 'false'}"
 							retry_max_interval "#{ENV['ES_RETRY_WAIT'] || '300'}"
 							retry_forever true
-							queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
+							queue_limit_length "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
 							chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m' }"
 							overflow_action "#{ENV['BUFFER_QUEUE_FULL_ACTION'] || 'block'}"
 						</buffer>
@@ -1177,7 +1130,7 @@ var _ = Describe("Generating fluentd config", func() {
 							flush_at_shutdown "#{ENV['FLUSH_AT_SHUTDOWN'] || 'false'}"
 							retry_max_interval "#{ENV['ES_RETRY_WAIT'] || '300'}"
 							retry_forever true
-							queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
+							queue_limit_length "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
 							chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m' }"
 							overflow_action "#{ENV['BUFFER_QUEUE_FULL_ACTION'] || 'block'}"
 						</buffer>
@@ -1220,28 +1173,13 @@ var _ = Describe("Generating fluentd config", func() {
 							flush_at_shutdown "#{ENV['FLUSH_AT_SHUTDOWN'] || 'false'}"
 							retry_max_interval "#{ENV['ES_RETRY_WAIT'] || '300'}"
 							retry_forever true
-							queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
+							queue_limit_length "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
 							chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m' }"
 							overflow_action "#{ENV['BUFFER_QUEUE_FULL_ACTION'] || 'block'}"
 						</buffer>
 					</store>
 				</match>
 			</label>
-			<label @_LEGACY_SECUREFORWARD>
-				<match **>
-				  @type copy
-					#include legacy secure-forward.conf
-					@include /etc/fluent/configs.d/secure-forward/secure-forward.conf
-				</match>
-			</label>
-			<label @_LEGACY_SYSLOG>
-				<match **>
-					@type copy
-					#include legacy Syslog
-					@include /etc/fluent/configs.d/syslog/syslog.conf
-				</match>
-			</label>
 			`)
 	})
-
 })
