@@ -73,7 +73,7 @@ var _ = Describe("LogForwarding prior to LF feature", func() {
 					Fail(fmt.Sprintf("Unable to create secure-forward secret: %v", err))
 				}
 
-				components := []helpers.LogComponentType{helpers.ComponentTypeCollector, helpers.ComponentTypeStore}
+				components := []helpers.LogComponentType{helpers.ComponentTypeCollector}
 				cr := helpers.NewClusterLogging(components...)
 				cr.ObjectMeta.Annotations[k8shandler.ForwardingAnnotation] = "disabled"
 				if err := e2e.CreateClusterLogging(cr); err != nil {
